@@ -103,9 +103,13 @@
 
         });
 
-        // Filters out unchanged selects and sortable field itself
+        // Filters out unchanged checkboxes, selects and sortable field itself
         function filter_unchanged(i, input) {
-            if (input.type == 'select-one' || input.type == 'select-multiple') {
+            if (input.type == 'checkbox') {
+                if (input.defaultChecked == input.checked) {
+                    return false;
+                }
+            } else if (input.type == 'select-one' || input.type == 'select-multiple') {
                 var options = input.options, option;
                 for (var j = 0; j < options.length; j++) {
                     option = options[j];
@@ -129,7 +133,7 @@
                 var i = 0, value;
                 $(selector).each(function () {
                     var $input = $(this);
-                    var fieldset_id = $input.attr('name').split('-')[0];
+                    var fieldset_id = $input.attr('name').split(/-\d+-/)[0];
                     // Check if any of new dynamic block values has been added
                     var $set_block = $input.closest('.dynamic-' + fieldset_id);
                     var $changed_fields = $set_block.find(":input[value!=''][type!='hidden']").filter(filter_unchanged);
